@@ -3,15 +3,16 @@ Main interface for dataexchange service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dataexchange import (
+    from mypy_boto3_dataexchange import (
         Client,
         DataExchangeClient,
         ListDataSetRevisionsPaginator,
         ListDataSetsPaginator,
         ListJobsPaginator,
         ListRevisionAssetsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,6 +23,7 @@ Usage::
     list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     list_revision_assets_paginator: ListRevisionAssetsPaginator = client.get_paginator("list_revision_assets")
+    ```
 """
 from mypy_boto3_dataexchange.client import DataExchangeClient, DataExchangeClient as Client
 from mypy_boto3_dataexchange.paginator import (
