@@ -3,8 +3,11 @@ Main interface for dataexchange service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dataexchange import (
+
+    from mypy_boto3_dataexchange import DataExchangeClient
+    from mypy_boto3_dataexchange import (
         ListDataSetRevisionsPaginator,
         ListDataSetsPaginator,
         ListJobsPaginator,
@@ -17,6 +20,7 @@ Usage::
     list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     list_revision_assets_paginator: ListRevisionAssetsPaginator = client.get_paginator("list_revision_assets")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -40,33 +44,33 @@ __all__ = (
 
 class ListDataSetRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDataSetRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
+    [Paginator.ListDataSetRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
     """
 
     def paginate(
         self, DataSetId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDataSetRevisionsResponseTypeDef]:
         """
-        [ListDataSetRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions.paginate)
+        [ListDataSetRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions.paginate)
         """
 
 
 class ListDataSetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDataSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
+    [Paginator.ListDataSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
     """
 
     def paginate(
         self, Origin: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDataSetsResponseTypeDef]:
         """
-        [ListDataSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets.paginate)
+        [ListDataSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets.paginate)
         """
 
 
 class ListJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
+    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
     """
 
     def paginate(
@@ -76,18 +80,18 @@ class ListJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListJobsResponseTypeDef]:
         """
-        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs.paginate)
+        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs.paginate)
         """
 
 
 class ListRevisionAssetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRevisionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
+    [Paginator.ListRevisionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
     """
 
     def paginate(
         self, DataSetId: str, RevisionId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListRevisionAssetsResponseTypeDef]:
         """
-        [ListRevisionAssets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.20/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets.paginate)
+        [ListRevisionAssets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets.paginate)
         """
