@@ -3,9 +3,11 @@ Main interface for dataexchange service type definitions.
 
 Usage::
 
-    from mypy_boto3.dataexchange.type_defs import OriginDetailsTypeDef
+    ```python
+    from mypy_boto3_dataexchange.type_defs import AssetDestinationEntryTypeDef
 
-    data: OriginDetailsTypeDef = {...}
+    data: AssetDestinationEntryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,51 +24,90 @@ else:
 
 
 __all__ = (
-    "OriginDetailsTypeDef",
-    "CreateDataSetResponseTypeDef",
-    "AssetSourceEntryTypeDef",
-    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
-    "DetailsTypeDef",
-    "JobErrorTypeDef",
-    "ExportAssetToSignedUrlResponseDetailsTypeDef",
     "AssetDestinationEntryTypeDef",
-    "ExportServerSideEncryptionTypeDef",
+    "AssetDetailsTypeDef",
+    "AssetEntryTypeDef",
+    "AssetSourceEntryTypeDef",
+    "DataSetEntryTypeDef",
+    "DetailsTypeDef",
+    "ExportAssetToSignedUrlRequestDetailsTypeDef",
+    "ExportAssetToSignedUrlResponseDetailsTypeDef",
+    "ExportAssetsToS3RequestDetailsTypeDef",
     "ExportAssetsToS3ResponseDetailsTypeDef",
+    "ExportServerSideEncryptionTypeDef",
+    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
+    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
     "ImportAssetFromSignedUrlResponseDetailsTypeDef",
+    "ImportAssetsFromS3RequestDetailsTypeDef",
     "ImportAssetsFromS3ResponseDetailsTypeDef",
+    "JobEntryTypeDef",
+    "JobErrorTypeDef",
+    "OriginDetailsTypeDef",
     "ResponseDetailsTypeDef",
+    "RevisionEntryTypeDef",
+    "S3SnapshotAssetTypeDef",
+    "CreateDataSetResponseTypeDef",
     "CreateJobResponseTypeDef",
     "CreateRevisionResponseTypeDef",
-    "S3SnapshotAssetTypeDef",
-    "AssetDetailsTypeDef",
     "GetAssetResponseTypeDef",
     "GetDataSetResponseTypeDef",
     "GetJobResponseTypeDef",
     "GetRevisionResponseTypeDef",
-    "RevisionEntryTypeDef",
     "ListDataSetRevisionsResponseTypeDef",
-    "DataSetEntryTypeDef",
     "ListDataSetsResponseTypeDef",
-    "JobEntryTypeDef",
     "ListJobsResponseTypeDef",
-    "AssetEntryTypeDef",
     "ListRevisionAssetsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "ExportAssetToSignedUrlRequestDetailsTypeDef",
-    "ExportAssetsToS3RequestDetailsTypeDef",
-    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
-    "ImportAssetsFromS3RequestDetailsTypeDef",
     "RequestDetailsTypeDef",
     "UpdateAssetResponseTypeDef",
     "UpdateDataSetResponseTypeDef",
     "UpdateRevisionResponseTypeDef",
 )
 
-OriginDetailsTypeDef = TypedDict("OriginDetailsTypeDef", {"ProductId": str})
+_RequiredAssetDestinationEntryTypeDef = TypedDict(
+    "_RequiredAssetDestinationEntryTypeDef", {"AssetId": str, "Bucket": str}
+)
+_OptionalAssetDestinationEntryTypeDef = TypedDict(
+    "_OptionalAssetDestinationEntryTypeDef", {"Key": str}, total=False
+)
 
-CreateDataSetResponseTypeDef = TypedDict(
-    "CreateDataSetResponseTypeDef",
+
+class AssetDestinationEntryTypeDef(
+    _RequiredAssetDestinationEntryTypeDef, _OptionalAssetDestinationEntryTypeDef
+):
+    pass
+
+
+AssetDetailsTypeDef = TypedDict(
+    "AssetDetailsTypeDef", {"S3SnapshotAsset": "S3SnapshotAssetTypeDef"}, total=False
+)
+
+_RequiredAssetEntryTypeDef = TypedDict(
+    "_RequiredAssetEntryTypeDef",
+    {
+        "Arn": str,
+        "AssetDetails": "AssetDetailsTypeDef",
+        "AssetType": Literal["S3_SNAPSHOT"],
+        "CreatedAt": datetime,
+        "DataSetId": str,
+        "Id": str,
+        "Name": str,
+        "RevisionId": str,
+        "UpdatedAt": datetime,
+    },
+)
+_OptionalAssetEntryTypeDef = TypedDict("_OptionalAssetEntryTypeDef", {"SourceId": str}, total=False)
+
+
+class AssetEntryTypeDef(_RequiredAssetEntryTypeDef, _OptionalAssetEntryTypeDef):
+    pass
+
+
+AssetSourceEntryTypeDef = TypedDict("AssetSourceEntryTypeDef", {"Bucket": str, "Key": str})
+
+_RequiredDataSetEntryTypeDef = TypedDict(
+    "_RequiredDataSetEntryTypeDef",
     {
         "Arn": str,
         "AssetType": Literal["S3_SNAPSHOT"],
@@ -75,60 +116,33 @@ CreateDataSetResponseTypeDef = TypedDict(
         "Id": str,
         "Name": str,
         "Origin": Literal["OWNED", "ENTITLED"],
-        "OriginDetails": OriginDetailsTypeDef,
-        "SourceId": str,
-        "Tags": Dict[str, str],
         "UpdatedAt": datetime,
     },
+)
+_OptionalDataSetEntryTypeDef = TypedDict(
+    "_OptionalDataSetEntryTypeDef",
+    {"OriginDetails": "OriginDetailsTypeDef", "SourceId": str},
     total=False,
 )
 
-AssetSourceEntryTypeDef = TypedDict("AssetSourceEntryTypeDef", {"Bucket": str, "Key": str})
 
-ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
-    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef", {"AssetName": str}
-)
+class DataSetEntryTypeDef(_RequiredDataSetEntryTypeDef, _OptionalDataSetEntryTypeDef):
+    pass
+
 
 DetailsTypeDef = TypedDict(
     "DetailsTypeDef",
     {
-        "ImportAssetFromSignedUrlJobErrorDetails": ImportAssetFromSignedUrlJobErrorDetailsTypeDef,
-        "ImportAssetsFromS3JobErrorDetails": List[AssetSourceEntryTypeDef],
+        "ImportAssetFromSignedUrlJobErrorDetails": "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
+        "ImportAssetsFromS3JobErrorDetails": List["AssetSourceEntryTypeDef"],
     },
     total=False,
 )
 
-_RequiredJobErrorTypeDef = TypedDict(
-    "_RequiredJobErrorTypeDef",
-    {
-        "Code": Literal[
-            "ACCESS_DENIED_EXCEPTION",
-            "INTERNAL_SERVER_EXCEPTION",
-            "MALWARE_DETECTED",
-            "RESOURCE_NOT_FOUND_EXCEPTION",
-            "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
-            "VALIDATION_EXCEPTION",
-            "MALWARE_SCAN_ENCRYPTED_FILE",
-        ],
-        "Message": str,
-    },
+ExportAssetToSignedUrlRequestDetailsTypeDef = TypedDict(
+    "ExportAssetToSignedUrlRequestDetailsTypeDef",
+    {"AssetId": str, "DataSetId": str, "RevisionId": str},
 )
-_OptionalJobErrorTypeDef = TypedDict(
-    "_OptionalJobErrorTypeDef",
-    {
-        "Details": DetailsTypeDef,
-        "LimitName": Literal["Assets per revision", "Asset size in GB"],
-        "LimitValue": float,
-        "ResourceId": str,
-        "ResourceType": Literal["REVISION", "ASSET"],
-    },
-    total=False,
-)
-
-
-class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
-    pass
-
 
 _RequiredExportAssetToSignedUrlResponseDetailsTypeDef = TypedDict(
     "_RequiredExportAssetToSignedUrlResponseDetailsTypeDef",
@@ -148,31 +162,38 @@ class ExportAssetToSignedUrlResponseDetailsTypeDef(
     pass
 
 
-_RequiredAssetDestinationEntryTypeDef = TypedDict(
-    "_RequiredAssetDestinationEntryTypeDef", {"AssetId": str, "Bucket": str}
+_RequiredExportAssetsToS3RequestDetailsTypeDef = TypedDict(
+    "_RequiredExportAssetsToS3RequestDetailsTypeDef",
+    {
+        "AssetDestinations": List["AssetDestinationEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
 )
-_OptionalAssetDestinationEntryTypeDef = TypedDict(
-    "_OptionalAssetDestinationEntryTypeDef", {"Key": str}, total=False
+_OptionalExportAssetsToS3RequestDetailsTypeDef = TypedDict(
+    "_OptionalExportAssetsToS3RequestDetailsTypeDef",
+    {"Encryption": "ExportServerSideEncryptionTypeDef"},
+    total=False,
 )
 
 
-class AssetDestinationEntryTypeDef(
-    _RequiredAssetDestinationEntryTypeDef, _OptionalAssetDestinationEntryTypeDef
+class ExportAssetsToS3RequestDetailsTypeDef(
+    _RequiredExportAssetsToS3RequestDetailsTypeDef, _OptionalExportAssetsToS3RequestDetailsTypeDef
 ):
     pass
 
 
-ExportServerSideEncryptionTypeDef = TypedDict(
-    "ExportServerSideEncryptionTypeDef", {"KmsKeyArn": str, "Type": Literal["aws:kms", "AES256"]}
-)
-
 _RequiredExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
     "_RequiredExportAssetsToS3ResponseDetailsTypeDef",
-    {"AssetDestinations": List[AssetDestinationEntryTypeDef], "DataSetId": str, "RevisionId": str},
+    {
+        "AssetDestinations": List["AssetDestinationEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
 )
 _OptionalExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
     "_OptionalExportAssetsToS3ResponseDetailsTypeDef",
-    {"Encryption": ExportServerSideEncryptionTypeDef},
+    {"Encryption": "ExportServerSideEncryptionTypeDef"},
     total=False,
 )
 
@@ -183,6 +204,19 @@ class ExportAssetsToS3ResponseDetailsTypeDef(
     pass
 
 
+ExportServerSideEncryptionTypeDef = TypedDict(
+    "ExportServerSideEncryptionTypeDef", {"KmsKeyArn": str, "Type": Literal["aws:kms", "AES256"]}
+)
+
+ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
+    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef", {"AssetName": str}
+)
+
+ImportAssetFromSignedUrlRequestDetailsTypeDef = TypedDict(
+    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
+    {"AssetName": str, "DataSetId": str, "Md5Hash": str, "RevisionId": str},
+)
+
 _RequiredImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
     "_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef",
     {"AssetName": str, "DataSetId": str, "RevisionId": str},
@@ -201,18 +235,118 @@ class ImportAssetFromSignedUrlResponseDetailsTypeDef(
     pass
 
 
+ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
+    "ImportAssetsFromS3RequestDetailsTypeDef",
+    {"AssetSources": List["AssetSourceEntryTypeDef"], "DataSetId": str, "RevisionId": str},
+)
+
 ImportAssetsFromS3ResponseDetailsTypeDef = TypedDict(
     "ImportAssetsFromS3ResponseDetailsTypeDef",
-    {"AssetSources": List[AssetSourceEntryTypeDef], "DataSetId": str, "RevisionId": str},
+    {"AssetSources": List["AssetSourceEntryTypeDef"], "DataSetId": str, "RevisionId": str},
 )
 
+_RequiredJobEntryTypeDef = TypedDict(
+    "_RequiredJobEntryTypeDef",
+    {
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Details": "ResponseDetailsTypeDef",
+        "Id": str,
+        "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
+        "Type": Literal[
+            "IMPORT_ASSETS_FROM_S3",
+            "IMPORT_ASSET_FROM_SIGNED_URL",
+            "EXPORT_ASSETS_TO_S3",
+            "EXPORT_ASSET_TO_SIGNED_URL",
+        ],
+        "UpdatedAt": datetime,
+    },
+)
+_OptionalJobEntryTypeDef = TypedDict(
+    "_OptionalJobEntryTypeDef", {"Errors": List["JobErrorTypeDef"]}, total=False
+)
+
+
+class JobEntryTypeDef(_RequiredJobEntryTypeDef, _OptionalJobEntryTypeDef):
+    pass
+
+
+_RequiredJobErrorTypeDef = TypedDict(
+    "_RequiredJobErrorTypeDef",
+    {
+        "Code": Literal[
+            "ACCESS_DENIED_EXCEPTION",
+            "INTERNAL_SERVER_EXCEPTION",
+            "MALWARE_DETECTED",
+            "RESOURCE_NOT_FOUND_EXCEPTION",
+            "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
+            "VALIDATION_EXCEPTION",
+            "MALWARE_SCAN_ENCRYPTED_FILE",
+        ],
+        "Message": str,
+    },
+)
+_OptionalJobErrorTypeDef = TypedDict(
+    "_OptionalJobErrorTypeDef",
+    {
+        "Details": "DetailsTypeDef",
+        "LimitName": Literal["Assets per revision", "Asset size in GB"],
+        "LimitValue": float,
+        "ResourceId": str,
+        "ResourceType": Literal["REVISION", "ASSET"],
+    },
+    total=False,
+)
+
+
+class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
+    pass
+
+
+OriginDetailsTypeDef = TypedDict("OriginDetailsTypeDef", {"ProductId": str})
+
 ResponseDetailsTypeDef = TypedDict(
     "ResponseDetailsTypeDef",
     {
-        "ExportAssetToSignedUrl": ExportAssetToSignedUrlResponseDetailsTypeDef,
-        "ExportAssetsToS3": ExportAssetsToS3ResponseDetailsTypeDef,
-        "ImportAssetFromSignedUrl": ImportAssetFromSignedUrlResponseDetailsTypeDef,
-        "ImportAssetsFromS3": ImportAssetsFromS3ResponseDetailsTypeDef,
+        "ExportAssetToSignedUrl": "ExportAssetToSignedUrlResponseDetailsTypeDef",
+        "ExportAssetsToS3": "ExportAssetsToS3ResponseDetailsTypeDef",
+        "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
+        "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
+    },
+    total=False,
+)
+
+_RequiredRevisionEntryTypeDef = TypedDict(
+    "_RequiredRevisionEntryTypeDef",
+    {"Arn": str, "CreatedAt": datetime, "DataSetId": str, "Id": str, "UpdatedAt": datetime},
+)
+_OptionalRevisionEntryTypeDef = TypedDict(
+    "_OptionalRevisionEntryTypeDef",
+    {"Comment": str, "Finalized": bool, "SourceId": str},
+    total=False,
+)
+
+
+class RevisionEntryTypeDef(_RequiredRevisionEntryTypeDef, _OptionalRevisionEntryTypeDef):
+    pass
+
+
+S3SnapshotAssetTypeDef = TypedDict("S3SnapshotAssetTypeDef", {"Size": float})
+
+CreateDataSetResponseTypeDef = TypedDict(
+    "CreateDataSetResponseTypeDef",
+    {
+        "Arn": str,
+        "AssetType": Literal["S3_SNAPSHOT"],
+        "CreatedAt": datetime,
+        "Description": str,
+        "Id": str,
+        "Name": str,
+        "Origin": Literal["OWNED", "ENTITLED"],
+        "OriginDetails": "OriginDetailsTypeDef",
+        "SourceId": str,
+        "Tags": Dict[str, str],
+        "UpdatedAt": datetime,
     },
     total=False,
 )
@@ -222,8 +356,8 @@ CreateJobResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "CreatedAt": datetime,
-        "Details": ResponseDetailsTypeDef,
-        "Errors": List[JobErrorTypeDef],
+        "Details": "ResponseDetailsTypeDef",
+        "Errors": List["JobErrorTypeDef"],
         "Id": str,
         "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
         "Type": Literal[
@@ -253,17 +387,11 @@ CreateRevisionResponseTypeDef = TypedDict(
     total=False,
 )
 
-S3SnapshotAssetTypeDef = TypedDict("S3SnapshotAssetTypeDef", {"Size": float})
-
-AssetDetailsTypeDef = TypedDict(
-    "AssetDetailsTypeDef", {"S3SnapshotAsset": S3SnapshotAssetTypeDef}, total=False
-)
-
 GetAssetResponseTypeDef = TypedDict(
     "GetAssetResponseTypeDef",
     {
         "Arn": str,
-        "AssetDetails": AssetDetailsTypeDef,
+        "AssetDetails": "AssetDetailsTypeDef",
         "AssetType": Literal["S3_SNAPSHOT"],
         "CreatedAt": datetime,
         "DataSetId": str,
@@ -286,7 +414,7 @@ GetDataSetResponseTypeDef = TypedDict(
         "Id": str,
         "Name": str,
         "Origin": Literal["OWNED", "ENTITLED"],
-        "OriginDetails": OriginDetailsTypeDef,
+        "OriginDetails": "OriginDetailsTypeDef",
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
@@ -299,8 +427,8 @@ GetJobResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "CreatedAt": datetime,
-        "Details": ResponseDetailsTypeDef,
-        "Errors": List[JobErrorTypeDef],
+        "Details": "ResponseDetailsTypeDef",
+        "Errors": List["JobErrorTypeDef"],
         "Id": str,
         "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
         "Type": Literal[
@@ -330,111 +458,25 @@ GetRevisionResponseTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredRevisionEntryTypeDef = TypedDict(
-    "_RequiredRevisionEntryTypeDef",
-    {"Arn": str, "CreatedAt": datetime, "DataSetId": str, "Id": str, "UpdatedAt": datetime},
-)
-_OptionalRevisionEntryTypeDef = TypedDict(
-    "_OptionalRevisionEntryTypeDef",
-    {"Comment": str, "Finalized": bool, "SourceId": str},
-    total=False,
-)
-
-
-class RevisionEntryTypeDef(_RequiredRevisionEntryTypeDef, _OptionalRevisionEntryTypeDef):
-    pass
-
-
 ListDataSetRevisionsResponseTypeDef = TypedDict(
     "ListDataSetRevisionsResponseTypeDef",
-    {"NextToken": str, "Revisions": List[RevisionEntryTypeDef]},
+    {"NextToken": str, "Revisions": List["RevisionEntryTypeDef"]},
     total=False,
 )
 
-_RequiredDataSetEntryTypeDef = TypedDict(
-    "_RequiredDataSetEntryTypeDef",
-    {
-        "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
-        "CreatedAt": datetime,
-        "Description": str,
-        "Id": str,
-        "Name": str,
-        "Origin": Literal["OWNED", "ENTITLED"],
-        "UpdatedAt": datetime,
-    },
-)
-_OptionalDataSetEntryTypeDef = TypedDict(
-    "_OptionalDataSetEntryTypeDef",
-    {"OriginDetails": OriginDetailsTypeDef, "SourceId": str},
-    total=False,
-)
-
-
-class DataSetEntryTypeDef(_RequiredDataSetEntryTypeDef, _OptionalDataSetEntryTypeDef):
-    pass
-
-
 ListDataSetsResponseTypeDef = TypedDict(
     "ListDataSetsResponseTypeDef",
-    {"DataSets": List[DataSetEntryTypeDef], "NextToken": str},
+    {"DataSets": List["DataSetEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
-_RequiredJobEntryTypeDef = TypedDict(
-    "_RequiredJobEntryTypeDef",
-    {
-        "Arn": str,
-        "CreatedAt": datetime,
-        "Details": ResponseDetailsTypeDef,
-        "Id": str,
-        "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
-        "Type": Literal[
-            "IMPORT_ASSETS_FROM_S3",
-            "IMPORT_ASSET_FROM_SIGNED_URL",
-            "EXPORT_ASSETS_TO_S3",
-            "EXPORT_ASSET_TO_SIGNED_URL",
-        ],
-        "UpdatedAt": datetime,
-    },
-)
-_OptionalJobEntryTypeDef = TypedDict(
-    "_OptionalJobEntryTypeDef", {"Errors": List[JobErrorTypeDef]}, total=False
-)
-
-
-class JobEntryTypeDef(_RequiredJobEntryTypeDef, _OptionalJobEntryTypeDef):
-    pass
-
-
 ListJobsResponseTypeDef = TypedDict(
-    "ListJobsResponseTypeDef", {"Jobs": List[JobEntryTypeDef], "NextToken": str}, total=False
+    "ListJobsResponseTypeDef", {"Jobs": List["JobEntryTypeDef"], "NextToken": str}, total=False
 )
 
-_RequiredAssetEntryTypeDef = TypedDict(
-    "_RequiredAssetEntryTypeDef",
-    {
-        "Arn": str,
-        "AssetDetails": AssetDetailsTypeDef,
-        "AssetType": Literal["S3_SNAPSHOT"],
-        "CreatedAt": datetime,
-        "DataSetId": str,
-        "Id": str,
-        "Name": str,
-        "RevisionId": str,
-        "UpdatedAt": datetime,
-    },
-)
-_OptionalAssetEntryTypeDef = TypedDict("_OptionalAssetEntryTypeDef", {"SourceId": str}, total=False)
-
-
-class AssetEntryTypeDef(_RequiredAssetEntryTypeDef, _OptionalAssetEntryTypeDef):
-    pass
-
-
 ListRevisionAssetsResponseTypeDef = TypedDict(
     "ListRevisionAssetsResponseTypeDef",
-    {"Assets": List[AssetEntryTypeDef], "NextToken": str},
+    {"Assets": List["AssetEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -446,45 +488,13 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-ExportAssetToSignedUrlRequestDetailsTypeDef = TypedDict(
-    "ExportAssetToSignedUrlRequestDetailsTypeDef",
-    {"AssetId": str, "DataSetId": str, "RevisionId": str},
-)
-
-_RequiredExportAssetsToS3RequestDetailsTypeDef = TypedDict(
-    "_RequiredExportAssetsToS3RequestDetailsTypeDef",
-    {"AssetDestinations": List[AssetDestinationEntryTypeDef], "DataSetId": str, "RevisionId": str},
-)
-_OptionalExportAssetsToS3RequestDetailsTypeDef = TypedDict(
-    "_OptionalExportAssetsToS3RequestDetailsTypeDef",
-    {"Encryption": ExportServerSideEncryptionTypeDef},
-    total=False,
-)
-
-
-class ExportAssetsToS3RequestDetailsTypeDef(
-    _RequiredExportAssetsToS3RequestDetailsTypeDef, _OptionalExportAssetsToS3RequestDetailsTypeDef
-):
-    pass
-
-
-ImportAssetFromSignedUrlRequestDetailsTypeDef = TypedDict(
-    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
-    {"AssetName": str, "DataSetId": str, "Md5Hash": str, "RevisionId": str},
-)
-
-ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
-    "ImportAssetsFromS3RequestDetailsTypeDef",
-    {"AssetSources": List[AssetSourceEntryTypeDef], "DataSetId": str, "RevisionId": str},
-)
-
 RequestDetailsTypeDef = TypedDict(
     "RequestDetailsTypeDef",
     {
-        "ExportAssetToSignedUrl": ExportAssetToSignedUrlRequestDetailsTypeDef,
-        "ExportAssetsToS3": ExportAssetsToS3RequestDetailsTypeDef,
-        "ImportAssetFromSignedUrl": ImportAssetFromSignedUrlRequestDetailsTypeDef,
-        "ImportAssetsFromS3": ImportAssetsFromS3RequestDetailsTypeDef,
+        "ExportAssetToSignedUrl": "ExportAssetToSignedUrlRequestDetailsTypeDef",
+        "ExportAssetsToS3": "ExportAssetsToS3RequestDetailsTypeDef",
+        "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlRequestDetailsTypeDef",
+        "ImportAssetsFromS3": "ImportAssetsFromS3RequestDetailsTypeDef",
     },
     total=False,
 )
@@ -493,7 +503,7 @@ UpdateAssetResponseTypeDef = TypedDict(
     "UpdateAssetResponseTypeDef",
     {
         "Arn": str,
-        "AssetDetails": AssetDetailsTypeDef,
+        "AssetDetails": "AssetDetailsTypeDef",
         "AssetType": Literal["S3_SNAPSHOT"],
         "CreatedAt": datetime,
         "DataSetId": str,
@@ -516,7 +526,7 @@ UpdateDataSetResponseTypeDef = TypedDict(
         "Id": str,
         "Name": str,
         "Origin": Literal["OWNED", "ENTITLED"],
-        "OriginDetails": OriginDetailsTypeDef,
+        "OriginDetails": "OriginDetailsTypeDef",
         "SourceId": str,
         "UpdatedAt": datetime,
     },
